nltk.tree package
=================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.tree.immutable
   nltk.tree.parented
   nltk.tree.parsing
   nltk.tree.prettyprinter
   nltk.tree.probabilistic
   nltk.tree.transforms
   nltk.tree.tree

Module contents
---------------

.. automodule:: nltk.tree
   :members:
   :undoc-members:
   :show-inheritance:
